Modifier class

Constructors

Modifier({Axis scrollDirection = Axis.horizontal, int initialPage = 0, bool reverse = false, double viewportFraction = 1.0, PageController? controller, ScrollPhysics? physics, bool pageSnapping = true, ValueChanged<int>? onPageChanged, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool allowImplicitScrolling = false, String? restorationId, Clip clipBehavior = Clip.hardEdge, ScrollBehavior? scrollBehavior, bool padEnds = true})
const

Properties

allowImplicitScrolling → bool
final
clipBehavior → Clip
final
controller → PageController?
final
dragStartBehavior → DragStartBehavior
final
hashCode → int
The hash code for this object.
no setterinherited
initialPage → int
final
onPageChanged → ValueChanged<int>?
final
padEnds → bool
final
pageSnapping → bool
final
physics → ScrollPhysics?
final
restorationId → String?
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior → ScrollBehavior?
final
scrollDirection → Axis
final
viewportFraction → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited